@@ -33,7 +33,9 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.055';
+use PPIx::Regexp::Constant qw{ @CARP_NOT };
+
+our $VERSION = '0.065';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -109,8 +111,11 @@ sub perl_version_introduced {
 # a reference to a hash to pass to make_token as the class-specific
 # arguments. The regular expression MUST be anchored to the beginning of
 # the string.
+# Note that we have to require a non-lowercase letter after the asterisk
+# to avoid grabbing the so-caled alpha_assertions introduced with
+# 5.27.9.
 sub __PPIX_TOKEN__recognize {
-    return ( [ qr{ \A \( \* [^\)]* \) }smx ] );
+    return ( [ qr{ \A \( \* (?! [[:lower:]] ) [^\)]* \) }smx ] );
 }
 
 # This class gets recognized by PPIx::Regexp::Token::Structure as part
@@ -143,7 +148,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
